@@ -1,8 +1,8 @@
 /*
  * NASPRO - The NASPRO Architecture for Sound PROcessing
- * Core library
+ * Portable runtime library
  *
- * Copyright (C) 2007-2013 NASPRO core development team
+ * Copyright (C) 2007-2014 Stefano D'Angelo
  *
  * See the COPYING file for license conditions.
  */
@@ -10,13 +10,13 @@
 /*
    Title: NASPRO core
 
-   *Version*: 0.5.0, *API*: 5.0.1.
+   *Version*: 0.5.1, *API*: 5.0.2.
 
    About:
 
      <NASPRO core at http://naspro.sourceforge.net/libraries.html#naspro-core>
-     is the portable runtime library at the bottom of the <NASPRO Sound
-     PROcessing Architecture at http://naspro.sourceforge.net/>.
+     is the portable runtime library at the bottom of the <NASPRO Architecture
+     for Sound PROcessing at http://naspro.sourceforge.net/>.
 
      It abstracts away some platform- and compiler-specific features, implements
      a small collection of abstract data types and provides a couple of useful
@@ -31,8 +31,8 @@
      platforms, assuming that malloc() and free() are thread-safe and errno is
      thread-local.
 
-     It should also work (but it's not yet "officially supported") on Windows XP
-     and later, 32 and 64 bit versions.
+     It should also work (but it's never been tested) on Windows XP and later,
+     32 and 64 bit versions.
 
      It has only been built and tested using the <GCC at http://gcc.gnu.org/>
      compiler, for which it has special support and whose version is supposed to
@@ -58,7 +58,7 @@
 
      * An environment capable of running Autotools-based build systems;
      * (optional) <GNU Autoconf at http://www.gnu.org/software/autoconf/> >=
-       2.68, <GNU Automake at http://www.gnu.org/software/automake/> and
+       2.69, <GNU Automake at http://www.gnu.org/software/automake/> and
        <GNU Libtool at http://www.gnu.org/software/libtool/> to regenerate the
        build system;
      * (optional) <Natural Docs at http://www.naturaldocs.org/> >= 1.5 to
