@@ -1,8 +1,8 @@
 /*
  * NASPRO - The NASPRO Architecture for Sound PROcessing
- * Core library
+ * Portable runtime library
  *
- * Copyright (C) 2007-2013 NASPRO core development team
+ * Copyright (C) 2007-2014 Stefano D'Angelo
  *
  * See the COPYING file for license conditions.
  */
@@ -787,16 +787,8 @@ conv_d(char *str, conv_spec *cs, va_list *ap, const char *dec_sep,
 
 	if (!((cs->precision == 0) && (v == 0)))
 	  {
-		if (v < 0)
-			for (i = 1, c = -1; c >= v; i++, c *= 10) ;
-		else
-			for (i = 1, c = 1; c < v; i++, c *= 10) ;
-
-		if (c != v)
-		  {
-			c /= 10;
-			i--;
-		  }
+		c = (v < 0) ? -1 : 1;
+		for (i = 1; v / c >= 10; i++, c *= 10) ;
 
 		if (i < cs->precision)
 			for (; i < cs->precision; cs->precision--)
@@ -861,13 +853,10 @@ conv_o(char *str, conv_spec *cs, va_list *ap, const char *dec_sep,
 
 	if (!((cs->precision == 0) && (v == 0)))
 	  {
-		for (i = 1, c = 1; c < v; i++, c <<= 3) ;
-
-		if (c != v)
-		  {
-			c >>= 3;
-			i--;
-		  }
+		c = (~(c & 0)) << 3;
+		for (i = 1; v & c; i++, c <<= 3) ;
+		c = 1;
+		c <<= 3 * (i - 1);
 
 		if (i < cs->precision)
 			for (; i < cs->precision; cs->precision--)
@@ -935,13 +924,7 @@ conv_u(char *str, conv_spec *cs, va_list *ap, const char *dec_sep,
 
 	if (!((cs->precision == 0) && (v == 0)))
 	  {
-		for (i = 1, c = 1; c < v; i++, c *= 10) ;
-
-		if (c != v)
-		  {
-			c /= 10;
-			i--;
-		  }
+		for (i = 1, c = 1; v / c >= 10; i++, c *= 10) ;
 
 		if (i < cs->precision)
 			for (; i < cs->precision; cs->precision--)
@@ -1005,13 +988,10 @@ conv_xX(char *str, conv_spec *cs, va_list *ap, char X)
 
 	if (!((cs->precision == 0) && (v == 0)))
 	  {
-		for (i = 1, c = 1; c < v; i++, c <<= 4) ;
-
-		if (c != v)
-		  {
-			c >>= 4;
-			i--;
-		  }
+		c = (~(c & 0)) << 4;
+		for (i = 1; v & c; i++, c <<= 4) ;
+		c = 1;
+		c <<= 4 * (i - 1);
 
 		if (cs->flags & FLAG_DASH)
 		  {
